@@ -62,6 +62,7 @@ class PersonMatcher:
                 self.add_name(chamber, name.name, person.id)
 
     def add_name(self, chamber: str, name_piece: str, id_: str) -> None:
+        name_piece = name_piece.lower()
         self.all_ids.add(id_)
         if name_piece in self.current_people[chamber]:
             self.current_people[chamber][name_piece].add(id_)
@@ -73,6 +74,7 @@ class PersonMatcher:
 
     @lru_cache(500)
     def match(self, chamber: str, name: str) -> typing.Optional[str]:
+        name = name.lower()
         candidates = self.current_people[chamber].get(name, None)
         if not candidates:
             click.secho(
@@ -165,6 +167,8 @@ def merge_lists(orig: list, new: list, key_attr: str) -> list:
     # add original items, or their replacements if present
     for item in orig:
         key = getattr(item, key_attr)
+        if key in seen:
+            continue
         seen.add(key)
         if key in new_by_key:
             combined.append(new_by_key[key])
@@ -177,31 +181,6 @@ def merge_lists(orig: list, new: list, key_attr: str) -> list:
     return combined
 
 
-def merge_committees(orig: Committee, new: ScrapeCommittee) -> Committee:
-    # disallow merge of these, likely error & unclear what should happen
-    if orig.chamber != new.chamber:
-        raise ValueError("cannot merge committees with different chambers")
-    if orig.parent != new.parent:
-        raise ValueError("cannot merge committees with different parents")
-    if orig.classification != new.classification:
-        raise ValueError("cannot merge committees with different classifications")
-    # TODO: jurisdiction isn't yet set on ScrapeCommittee... do we need another check here?
-
-    merged = Committee(
-        id=orig.id,  # id stays constant
-        chamber=orig.chamber,
-        parent=orig.parent,
-        classification=orig.classification,
-        jurisdiction=orig.jurisdiction,
-        name=new.name,  # name can be updated
-        sources=merge_lists(orig.sources, new.sources, "url"),
-        links=merge_lists(orig.links, new.links, "url"),
-        other_names=merge_lists(orig.other_names, new.other_names, "name"),
-        members=merge_lists(orig.members, new.members, "name"),
-    )
-    return merged
-
-
 class CommitteeDir:
     def __init__(
         self,
@@ -232,6 +211,39 @@ class CommitteeDir:
                     raise
                 self.errors.append((filename, ve))
 
+    def merge_committees(self, orig: Committee, new: ScrapeCommittee) -> Committee:
+        # need new parent id
+        new_parent_id = None
+        if new.parent:
+            new_parent_id = self.coms_by_chamber_and_name[new.chamber][new.parent].id
+
+        # disallow merge of these, likely error & unclear what should happen
+        if orig.chamber != new.chamber:
+            raise ValueError("cannot merge committees with different chambers")
+        if orig.parent != new_parent_id:
+            print(orig)
+            print(new_parent_id)
+            print(new)
+            raise ValueError("cannot merge committees with different parents")
+        if orig.classification != new.classification:
+            raise ValueError("cannot merge committees with different classifications")
+        # TODO: jurisdiction isn't yet set on ScrapeCommittee... do we need another check here?
+
+        merged = Committee(
+            id=orig.id,  # id stays constant
+            chamber=orig.chamber,
+            parent=orig.parent,
+            classification=orig.classification,
+            jurisdiction=orig.jurisdiction,
+            name=new.name,  # name can be updated
+            sources=merge_lists(orig.sources, new.sources, "url"),
+            links=merge_lists(orig.links, new.links, "url"),
+            other_names=merge_lists(orig.other_names, new.other_names, "name"),
+            members=merge_lists(orig.members, new.members, "name"),
+            extras=orig.extras | new.extras,
+        )
+        return merged
+
     def print_warnings(self) -> None:
         unmatched_names = set()
         for coms_for_chamber in self.coms_by_chamber_and_name.values():
@@ -315,6 +327,9 @@ class CommitteeDir:
         for filename in Path(input_dir).glob("*"):
             with open(filename) as file:
                 data = json.load(file)
+                if not data:
+                    click.secho(f"no committee in {filename}", fg="yellow")
+                    continue
                 com = ScrapeCommittee(**data)
                 # do person matching on import so that diffs work
                 for member in com.members:
@@ -371,7 +386,7 @@ class CommitteeDir:
                 com_without_id.pop("id")
                 com_without_id.pop("jurisdiction")
                 rev_sc = ScrapeCommittee(**com_without_id)
-                if com != rev_sc:
+                if com != rev_sc and com.parent == rev_sc.parent:
                     to_merge.append((existing, com))
                 else:
                     same += 1
@@ -443,7 +458,8 @@ def main() -> None:
 @main.command()  # pragma: no cover
 @click.argument("abbr")
 @click.argument("input_dir")
-def merge(abbr: str, input_dir: str) -> None:
+@click.option("--interactive/--no-interactive", default=False)
+def merge(abbr: str, input_dir: str, interactive: bool) -> None:
     """
     Merge scraped committee data into repo.
     """
@@ -472,7 +488,7 @@ def merge(abbr: str, input_dir: str) -> None:
         )
 
         if plan.names_to_add or plan.names_to_remove or plan.to_merge:
-            if not click.confirm("Do you wish to continue?"):
+            if interactive and not click.confirm("Do you wish to continue?"):
                 sys.exit(1)
 
             # add new committees
@@ -490,7 +506,7 @@ def merge(abbr: str, input_dir: str) -> None:
 
             # merge remaining committees
             for orig, new in plan.to_merge:
-                merged = merge_committees(orig, new)
+                merged = comdir.merge_committees(orig, new)
                 comdir.save_committee(merged)
         else:
             click.secho("nothing to do!", fg="green")
