@@ -77,10 +77,10 @@ class Summarizer:
             if p_role.is_active():
                 self.parties[p_role.name] += 1
 
-        for cd in person.contact_details:
+        for cd in person.offices:
             for key in ("voice", "fax", "address"):
                 if getattr(cd, key, None):
-                    self.contact_counts[cd.note + " " + key] += 1
+                    self.contact_counts[cd.classification + " " + key] += 1
 
         for scheme, id_ in person.ids or []:
             if id_:
@@ -190,18 +190,15 @@ def write_csv(files: list[Path], jurisdiction_id: str, output_filename: str) ->
 
             district_address = district_voice = district_fax = None
             capitol_address = capitol_voice = capitol_fax = None
-            for cd in person.contact_details:
-                note = cd.note.lower()
-                if "district" in note:
+            for cd in person.offices:
+                if cd.classification == "district":
                     district_address = cd.address
                     district_voice = cd.voice
                     district_fax = cd.fax
-                elif "capitol" in note:
+                elif cd.classification == "district":
                     capitol_address = cd.address
                     capitol_voice = cd.voice
                     capitol_fax = cd.fax
-                else:
-                    click.secho("unknown office: " + note, fg="red")
 
             links = ";".join(k.url for k in person.links)
             sources = ";".join(k.url for k in person.sources)
@@ -698,7 +695,12 @@ def to_database(abbreviations: list[str], purge: bool, safe: bool) -> None:
     default=None,
     help="Set retirement date for all people marked retired.",
 )
-def merge(abbr: str, input_dir: str, retirement: str) -> None:
+@click.option(
+    "--reset-offices",
+    is_flag=True,
+    help="Reset offices to latest scrape instead of trying to merge old with new.",
+)
+def merge(abbr: str, input_dir: str, retirement: str, reset_offices: bool) -> None:
     """
     Convert scraped JSON in INPUT_DIR to YAML files for this repo.
     """
@@ -718,7 +720,9 @@ def merge(abbr: str, input_dir: str, retirement: str) -> None:
         f"analyzing {len(existing_people)} existing people and {len(new_people)} scraped"
     )
 
-    unmatched = incoming_merge(abbr, existing_people, new_people, retirement)
+    unmatched = incoming_merge(
+        abbr, existing_people, new_people, retirement, reset_offices
+    )
     click.secho(f"{len(unmatched)} people were unmatched")
 
 
