@@ -1,3 +1,4 @@
+import typing
 import os
 import json
 import pytz
@@ -5,23 +6,23 @@ import datetime
 import subprocess
 
 
-def utcnow():
+def utcnow() -> datetime.datetime:
     return datetime.datetime.now(datetime.timezone.utc)
 
 
-def _make_pseudo_id(**kwargs):
+def _make_pseudo_id(**kwargs: str) -> str:
     """ pseudo ids are just JSON """
     # ensure keys are sorted so that these are deterministic
     return "~" + json.dumps(kwargs, sort_keys=True)
 
 
-def get_pseudo_id(pid):
+def get_pseudo_id(pid: str) -> dict[str, typing.Any]:
     if pid[0] != "~":
         raise ValueError("pseudo id doesn't start with ~")
     return json.loads(pid[1:])
 
 
-def makedirs(dname):
+def makedirs(dname: str) -> None:
     if not os.path.isdir(dname):
         os.makedirs(dname)
 
@@ -31,7 +32,7 @@ class JSONEncoderPlus(json.JSONEncoder):
     JSONEncoder that encodes datetime objects as Unix timestamps.
     """
 
-    def default(self, obj, **kwargs):
+    def default(self, obj, **kwargs):  # type: ignore
         if isinstance(obj, datetime.datetime):
             if obj.tzinfo is None:
                 raise TypeError("date '%s' is not fully timezone qualified." % (obj))
@@ -42,7 +43,7 @@ class JSONEncoderPlus(json.JSONEncoder):
         return super(JSONEncoderPlus, self).default(obj, **kwargs)
 
 
-def convert_pdf(filename, type="xml"):
+def convert_pdf(filename: str, type: str = "xml") -> bytes:
     commands = {
         "text": ["pdftotext", "-layout", filename, "-"],
         "text-nolayout": ["pdftotext", filename, "-"],
@@ -55,12 +56,18 @@ def convert_pdf(filename, type="xml"):
         ).stdout
     except OSError as e:
         raise EnvironmentError(
-            "error running %s, missing executable? [%s]" % " ".join(commands[type]), e
+            "error running {}, missing executable? [{}]".format(
+                " ".join(commands[type]), e
+            )
+        )
+    if not pipe:
+        raise EnvironmentError(
+            "error running {}, no pipe".format(" ".join(commands[type]))
         )
     data = pipe.read()
     pipe.close()
     return data
 
 
-def format_datetime(dt, timezone):
+def format_datetime(dt: datetime.datetime, timezone: str) -> str:
     return pytz.timezone(timezone).localize(dt).replace(microsecond=0).isoformat()
